@@ -12,6 +12,7 @@
 from time import sleep
 from numbers import Number
 from PiLCDControl import _LCDControl
+from RPi.GPIO import GPIO
 
 
 class LCD:
@@ -132,3 +133,17 @@ class LCD:
         """
         assert line == 1 or line == 2, "Invalid line value."
         self.lcd_control.stop_scroll_thread(line)
+
+    def cleanup(self):
+        """
+        Clears the display and performs GPIO cleanup.
+
+        Returns
+        -------
+        None
+        """
+        self.display_text("", 1)
+        self.display_text("", 2)
+        self.stop_scroll(1)
+        self.stop_scroll(2)
+        GPIO.cleanup()
